Skip to contents

Get the input count data to pass directly to stan

Usage

get_input_count_data_for_stan(preprocessed_count_data, date_time_spine)

Arguments

preprocessed_count_data

a dataframe with the input count data, must have a column named date.

date_time_spine

table mapping dates to model time index, as the output of get_date_time_spine().

Value

data frame of count data passed to stan