Get the input count data to pass directly to stan
Source:R/get_stan_data.R
get_input_count_data_for_stan.RdGet the input count data to pass directly to stan
Arguments
- preprocessed_count_data
a dataframe with the input count data, must have a column named
date.- date_time_spine
table mapping dates to model time index, as the output of
get_date_time_spine().